==> deepin-ocr_6.5.0.tar.xz: BUILD/translations/deepin-ocr_am_ET.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="am_ET" version="2.1">
<context>
    <name>MainWidget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="166"/>
        <source>No text recognized</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="214"/>
        <source>Copy text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="221"/>
        <source>Save as TXT</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="273"/>
        <location filename="../src/mainwidget.cpp" line="314"/>
        <source>Recognizing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="514"/>
        <source>Copied</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="56"/>
        <source>OCR Tool</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <location filename="../src/resulttextview.cpp" line="15"/>
        <source>Copy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="17"/>
        <source>Cut</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="20"/>
        <source>Select All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="22"/>
        <source>Paste</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="262"/>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-ocr_6.5.12.tar.xz: BUILD/translations/deepin-ocr_am_ET.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="am_ET">
<context>
    <name>MainWidget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="166"/>
        <source>No text recognized</source>
        <translation>տեքստ չի ճանաչվել</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="214"/>
        <source>Copy text</source>
        <translation>տեքստը անգրագիտել</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="221"/>
        <source>Save as TXT</source>
        <translation>TXT որպես պահպանել</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="273"/>
        <source>Recognizing</source>
        <translation>ճանաչում է</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="514"/>
        <source>Copied</source>
        <translation>անգրագիտվել է</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="56"/>
        <source>OCR Tool</source>
        <translation>OCR գործիքը</translation>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <location filename="../src/resulttextview.cpp" line="15"/>
        <source>Copy</source>
        <translation>անգրագիտել</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="17"/>
        <source>Cut</source>
        <translation>անգրագիտել և կտրել</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="20"/>
        <source>Select All</source>
        <translation>բոլորը ընտրել</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="22"/>
        <source>Paste</source>
        <translation>փոխադրել</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="262"/>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation>Խորացուցիչ տեսանյութի դեպքում տեքստը ավելի ճշգրիտ է</translation>
    </message>
</context>
</TS>
